pub struct TopicBus { /* private fields */ }Expand description
In-process topic bus: maps fully-resolved topic names to shared slots.
Implementations
Sourceimpl TopicBus
impl TopicBus
Sourcepub fn get_or_create(&mut self, topic: &str, depth: usize) -> Arc<TopicSlot>
pub fn get_or_create(&mut self, topic: &str, depth: usize) -> Arc<TopicSlot>
Get or create the slot for topic using the caller-supplied depth.
Once a slot is created its depth is fixed for the lifetime of the bus.
Sourcepub fn get_or_create_default(&mut self, topic: &str) -> Arc<TopicSlot>
pub fn get_or_create_default(&mut self, topic: &str) -> Arc<TopicSlot>
Get or create with the bus-wide default depth.
pub fn set_reliability_policy( &mut self, reliability_policy: TopicReliabilityPolicy, )
pub fn load_entries(&self) -> Vec<TopicLoadEntry>